"""
MDIS - Malware Detection and Identification System
--------------------------------------------------

A minimal yet expressive malware identifier system,
designed for fast parsing, clarity, and extensibility.
"""

from .mdis import (
    MDISParser,
    MDISParserError,
    DICTIONARIES,
)
